@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <config/libraries.h>
 
+class Webserver_Request;
+
 std::string bible_book_url ();
-bool bible_book_acl (void * webserver_request);
-std::string bible_book (void * webserver_request);
+bool bible_book_acl (Webserver_Request& webserver_request);
+std::string bible_book (Webserver_Request& webserver_request);
