@@ -15,6 +15,6 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
-$(document).ready(function() {
+document.addEventListener("DOMContentLoaded", function(e) {
   navigationSetup ();
 });
