@@ -32,7 +32,7 @@
 #include <demo/logic.h>
 #include <sendreceive/logic.h>
 #include <access/bible.h>
-#include <dialog/list.h>
+#include <dialog/select.h>
 #include <checks/logic.h>
 #include <assets/header.h>
 #include <menu/logic.h>
@@ -50,7 +50,7 @@ bool checks_settings_acl ([[maybe_unused]] Webserver_Request& webserver_request)
 #ifdef HAVE_CLIENT
   return true;
 #else
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  return roles::access_control (webserver_request, roles::manager);
 #endif
 }
 
@@ -62,34 +62,34 @@ std::string checks_settings (Webserver_Request& webserver_request)
   header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
   page = header.run ();
   Assets_View view {};
+    
   
-  
-  if (webserver_request.query.count ("bible")) {
-    const std::string bible = webserver_request.query["bible"];
-    if (bible.empty()) {
-      Dialog_List dialog_list = Dialog_List ("settings", translate("Select which Bible to manage"), std::string(), std::string());
-      std::vector <std::string> bibles = access_bible::bibles (webserver_request);
-      for (const auto & selectable_bible : bibles) {
-        dialog_list.add_row (selectable_bible, "bible", selectable_bible);
-      }
-      page += dialog_list.run ();
-      return page;
-    } else {
-      webserver_request.database_config_user()->setBible (bible);
+  {
+    constexpr const char* identification {"bible"};
+    if (webserver_request.post_count (identification)) {
+      const std::string bible {webserver_request.post_get(identification)};
+      webserver_request.database_config_user()->set_bible (bible);
     }
+    dialog::select::Settings settings {
+      .identification = identification,
+      .values = access_bible::bibles (webserver_request),
+      .selected = access_bible::clamp (webserver_request, webserver_request.database_config_user()->get_bible ()),
+    };
+    dialog::select::Form form { .auto_submit = true };
+    view.set_variable(identification, dialog::select::form(settings, form));
   }
-  const std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->getBible ());
+  const std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->get_bible ());
 
   
   if (webserver_request.query.count ("run")) {
-    checks_logic_start (bible);
+    checks::logic::start (bible);
     view.set_variable ("success", translate("Will run the checks."));
     view.set_variable ("journal", journal_logic_see_journal_for_progress ());
   }
   
   
-  const std::string checkbox = webserver_request.post ["checkbox"];
-  const bool checked = filter::strings::convert_to_bool (webserver_request.post ["checked"]);
+  const std::string checkbox = webserver_request.post_get("checkbox");
+  const bool checked = filter::strings::convert_to_bool (webserver_request.post_get("checked"));
   
                         
   if (checkbox == "doublespacesusfm") {
@@ -194,9 +194,6 @@ std::string checks_settings (Webserver_Request& webserver_request)
   view.set_variable ("validutf8", filter::strings::get_checkbox_status (database::config::bible::get_check_valid_utf8_text (bible)));
 
   
-  view.set_variable ("bible", bible);
-
-  
 #ifdef HAVE_CLIENT
   view.enable_zone ("client");
 #else
