@@ -32,7 +32,6 @@
 #include <client/logic.h>
 #include <demo/logic.h>
 #include <sendreceive/logic.h>
-#include <dialog/list.h>
 #include <resource/logic.h>
 #include <menu/logic.h>
 
@@ -45,7 +44,7 @@ std::string consistency_index_url ()
 
 bool consistency_index_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
+  return roles::access_control (webserver_request, roles::translator);
 }
 
 
@@ -58,24 +57,24 @@ std::string consistency_index (Webserver_Request& webserver_request)
   Assets_View view;
 
   
-  std::string add = webserver_request.post ["add"];
+  std::string add = webserver_request.post_get("add");
   if (!add.empty ()) {
-    std::vector <std::string> resources = webserver_request.database_config_user()->getConsistencyResources ();
+    std::vector <std::string> resources = webserver_request.database_config_user()->get_consistency_resources ();
     resources.push_back (add);
-    webserver_request.database_config_user()->setConsistencyResources (resources);
+    webserver_request.database_config_user()->set_consistency_resources (resources);
   }
   
   
   std::string remove = webserver_request.query ["remove"];
   if (!remove.empty ()) {
-    std::vector <std::string> resources = webserver_request.database_config_user()->getConsistencyResources ();
+    std::vector <std::string> resources = webserver_request.database_config_user()->get_consistency_resources ();
     resources = filter::strings::array_diff (resources, {remove});
-    webserver_request.database_config_user()->setConsistencyResources (resources);
+    webserver_request.database_config_user()->set_consistency_resources (resources);
   }
   
   
   std::stringstream resourceblock;
-  std::vector <std::string> resources = webserver_request.database_config_user()->getConsistencyResources ();
+  std::vector <std::string> resources = webserver_request.database_config_user()->get_consistency_resources ();
   for (auto resource : resources) {
     resourceblock << resource;
     resourceblock << "\n";
