@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,46 +22,45 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <database/sqlite.h>
 #include <database/logic.h>
-using namespace std;
 
 
 // Database resilience:
 // Data is stored in multiple text files.
 
 
-string Database_NoteAssignment::path (string user)
+std::string Database_NoteAssignment::path (std::string user)
 {
   return filter_url_create_root_path ({database_logic_databases (), "client", "noteassignment_" + user + ".txt"});
 }
 
 
-bool Database_NoteAssignment::exists (string user)
+bool Database_NoteAssignment::exists (std::string user)
 {
   return file_or_dir_exists (path (user));
 }
 
 
-void Database_NoteAssignment::assignees (string user, vector <string> assignees)
+void Database_NoteAssignment::assignees (std::string user, std::vector <std::string> assignees)
 {
-  filter_url_file_put_contents (path (user), filter_string_implode (assignees, "\n"));
+  filter_url_file_put_contents (path (user), filter::strings::implode (assignees, "\n"));
 }
 
 
-vector <string> Database_NoteAssignment::assignees (string user)
+std::vector <std::string> Database_NoteAssignment::assignees (std::string user)
 {
-  string contents = filter_url_file_get_contents (path (user));
-  return filter_string_explode (contents, '\n');
+  std::string contents = filter_url_file_get_contents (path (user));
+  return filter::strings::explode (contents, '\n');
 }
 
 
-bool Database_NoteAssignment::exists (string user, string assignee)
+bool Database_NoteAssignment::exists (std::string user, std::string assignee)
 {
-  vector <string> users = assignees (user);
+  std::vector <std::string> users = assignees (user);
   return in_array (assignee, users);
 }
 
 
-void Database_NoteAssignment::remove (string user)
+void Database_NoteAssignment::remove (std::string user)
 {
   filter_url_unlink (path (user));
 }
