@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <config/globals.h>
 #include <database/sqlite.h>
-using namespace std;
 
 
 // This is the database for the Hebrew Bible text plus lemmas and morphology.
@@ -81,10 +80,10 @@ void Database_OsHb::optimize ()
 
 
 // Get Hebrew words for $book $chapter $verse.
-vector <string> Database_OsHb::getVerse (int book, int chapter, int verse)
+std::vector <std::string> Database_OsHb::getVerse (int book, int chapter, int verse)
 {
-  vector <string> words;
-  vector <int> rows = rowids (book, chapter, verse);
+  std::vector <std::string> words;
+  std::vector <int> rows = rowids (book, chapter, verse);
   for (auto row : rows) {
     words.push_back (word (row));
   }
@@ -93,22 +92,22 @@ vector <string> Database_OsHb::getVerse (int book, int chapter, int verse)
 
 
 // Get array of book / chapter / verse of all passages that contain a $hebrew word.
-vector <Passage> Database_OsHb::searchHebrew (string hebrew)
+std::vector <Passage> Database_OsHb::searchHebrew (std::string hebrew)
 {
   int word_id = get_id ("word", hebrew);
   SqliteDatabase sql = SqliteDatabase (filename ());
   sql.add ("SELECT DISTINCT book, chapter, verse FROM oshb WHERE word =");
   sql.add (word_id);
   sql.add ("ORDER BY book, chapter, verse ASC;");
-  vector <Passage> hits;
-  map <string, vector <string> > result = sql.query ();
-  vector <string> books = result ["book"];
-  vector <string> chapters = result ["chapter"];
-  vector <string> verses = result ["verse"];
+  std::vector <Passage> hits;
+  std::map <std::string, std::vector <std::string> > result = sql.query ();
+  std::vector <std::string> books = result ["book"];
+  std::vector <std::string> chapters = result ["chapter"];
+  std::vector <std::string> verses = result ["verse"];
   for (unsigned int i = 0; i < books.size (); i++) {
     Passage passage;
-    passage.m_book = convert_to_int (books [i]);
-    passage.m_chapter = convert_to_int (chapters [i]);
+    passage.m_book = filter::strings::convert_to_int (books [i]);
+    passage.m_chapter = filter::strings::convert_to_int (chapters [i]);
     passage.m_verse = verses [i];
     hits.push_back (passage);
   }
@@ -116,7 +115,7 @@ vector <Passage> Database_OsHb::searchHebrew (string hebrew)
 }
 
 
-void Database_OsHb::store (int book, int chapter, int verse, string lemma, string word, string morph)
+void Database_OsHb::store (int book, int chapter, int verse, std::string lemma, std::string word, std::string morph)
 {
   int lemma_id = get_id ("lemma", lemma);
   int word_id = get_id ("word", word);
@@ -148,7 +147,7 @@ void Database_OsHb::store (int book, int chapter, int verse, string lemma, strin
 }
 
 
-vector <int> Database_OsHb::rowids (int book, int chapter, int verse)
+std::vector <int> Database_OsHb::rowids (int book, int chapter, int verse)
 {
   SqliteDatabase sql = SqliteDatabase (filename ());
   sql.add ("SELECT rowid FROM oshb WHERE book =");
@@ -158,32 +157,32 @@ vector <int> Database_OsHb::rowids (int book, int chapter, int verse)
   sql.add ("AND verse =");
   sql.add (verse);
   sql.add ("ORDER BY rowid;");
-  vector <string> result = sql.query () ["rowid"];
-  vector <int> rowids;
-  for (auto rowid : result) rowids.push_back (convert_to_int (rowid));
+  std::vector <std::string> result = sql.query () ["rowid"];
+  std::vector <int> rowids;
+  for (auto rowid : result) rowids.push_back (filter::strings::convert_to_int (rowid));
   return rowids;
 }
 
 
-string Database_OsHb::lemma (int rowid)
+std::string Database_OsHb::lemma (int rowid)
 {
   return get_item ("lemma", rowid);
 }
 
 
-string Database_OsHb::word (int rowid)
+std::string Database_OsHb::word (int rowid)
 {
   return get_item ("word", rowid);
 }
 
 
-string Database_OsHb::morph (int rowid)
+std::string Database_OsHb::morph (int rowid)
 {
   return get_item ("morph", rowid);
 }
 
 
-int Database_OsHb::get_id (const char * table_row, string item)
+int Database_OsHb::get_id (const char * table_row, std::string item)
 {
   SqliteDatabase sql = SqliteDatabase (filename ());
   // Two iterations to be sure a rowid can be returned.
@@ -197,8 +196,8 @@ int Database_OsHb::get_id (const char * table_row, string item)
     sql.add ("=");
     sql.add (item);
     sql.add (";");
-    vector <string> result = sql.query () ["rowid"];
-    if (!result.empty ()) return convert_to_int (result [0]);
+    std::vector <std::string> result = sql.query () ["rowid"];
+    if (!result.empty ()) return filter::strings::convert_to_int (result [0]);
     // The rowid was not found: Insert the word into the table.
     // The rowid will now be found during the second iteration.
     sql.clear ();
@@ -213,7 +212,7 @@ int Database_OsHb::get_id (const char * table_row, string item)
 }
 
 
-string Database_OsHb::get_item (const char * item, int rowid)
+std::string Database_OsHb::get_item (const char * item, int rowid)
 {
   // The $rowid refers to the main table.
   // Update it so it refers to the sub table.
@@ -223,9 +222,9 @@ string Database_OsHb::get_item (const char * item, int rowid)
   sql.add ("FROM oshb WHERE rowid =");
   sql.add (rowid);
   sql.add (";");
-  vector <string> result = sql.query () [item];
+  std::vector <std::string> result = sql.query () [item];
   rowid = 0;
-  if (!result.empty ()) rowid = convert_to_int (result [0]);
+  if (!result.empty ()) rowid = filter::strings::convert_to_int (result [0]);
   // Retrieve the requested value from the sub table.
   sql.clear ();
   sql.add ("SELECT");
@@ -238,5 +237,5 @@ string Database_OsHb::get_item (const char * item, int rowid)
   result = sql.query () [item];
   if (!result.empty ()) return result [0];
   // Not found.
-  return "";
+  return std::string();
 }
