@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2022 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/url.h>
 #include <filter/string.h>
 #include <database/logic.h>
-using namespace std;
 
 
 // This database is resilient.
@@ -32,13 +31,13 @@ using namespace std;
 
 
 // The name of the database.
-const char * Database_Privileges::database ()
+const char * DatabasePrivileges::database ()
 {
   return "privileges";
 }
 
 
-void Database_Privileges::create ()
+void DatabasePrivileges::create ()
 {
   SqliteDatabase sql (database ());
   
@@ -58,16 +57,16 @@ void Database_Privileges::create ()
 }
 
 
-void Database_Privileges::upgrade ()
+void DatabasePrivileges::upgrade ()
 {
 }
 
 
-void Database_Privileges::optimize ()
+void DatabasePrivileges::optimize ()
 {
   // Recreate damaged database.
   if (!healthy ()) {
-    filter_url_unlink (database_sqlite_file (database ()));
+    filter_url_unlink (database::sqlite::get_file (database ()));
     create ();
   }
   // Vacuum it.
@@ -81,57 +80,57 @@ void Database_Privileges::optimize ()
 }
 
 
-bool Database_Privileges::healthy ()
+bool DatabasePrivileges::healthy ()
 {
-  return database_sqlite_healthy (database ());
+  return database::sqlite::healthy (database ());
 }
 
 
-string Database_Privileges::save (string username)
+std::string DatabasePrivileges::save (const std::string& username)
 {
   SqliteDatabase sql (database ());
   
-  vector <string> lines;
+  std::vector <std::string> lines {};
 
-  lines.push_back (bibles_start ());
+  lines.emplace_back (bibles_start ());
   sql.add ("SELECT bible, book, write FROM bibles WHERE username =");
   sql.add (username);
   sql.add (";");
-  map <string, vector <string> > result = sql.query ();
-  vector <string> bible = result ["bible"];
-  vector <string> book =  result ["book"];
-  vector <string> write = result ["write"];
+  std::map <std::string, std::vector <std::string> > result = sql.query ();
+  std::vector <std::string> bible = result ["bible"];
+  std::vector <std::string> book =  result ["book"];
+  std::vector <std::string> write = result ["write"];
   for (size_t i = 0; i < bible.size (); i++) {
-    lines.push_back (bible [i]);
-    lines.push_back (book [i]);
+    lines.emplace_back (bible [i]);
+    lines.emplace_back (book [i]);
     // It could have just stored 0 or 1 for the boolean values.
     // But if that were done, then there would be no change in the length of the file
     // when changing only boolean values.
     // And then the client would not re-download that file.
     // To use "on" and "off", that solves the issue.
-    bool b = convert_to_bool (write[i]);
-    if (b) lines.push_back (on ());
-    else lines.push_back (off ());
+    const bool b = filter::strings::convert_to_bool (write[i]);
+    if (b) lines.emplace_back (on ());
+    else lines.emplace_back (off ());
   }
-  lines.push_back (bibles_end ());
+  lines.emplace_back (bibles_end ());
   
-  lines.push_back (features_start ());
+  lines.emplace_back (features_start ());
   sql.clear ();
   sql.add ("SELECT feature FROM features WHERE username =");
   sql.add (username);
   sql.add (";");
   result = sql.query ();
-  vector <string> feature = result ["feature"];
+  const std::vector <std::string> feature = result ["feature"];
   for (size_t i = 0; i < feature.size (); i++) {
-    lines.push_back (feature [i]);
+    lines.emplace_back (feature [i]);
   }
-  lines.push_back (features_end ());
+  lines.emplace_back (features_end ());
   
-  return filter_string_implode (lines, "\n");
+  return filter::strings::implode (lines, "\n");
 }
 
 
-void Database_Privileges::load (string username, const string & data)
+void DatabasePrivileges::load (const std::string& username, const std::string& data)
 {
   // Clear all data for the user.
   {
@@ -146,16 +145,16 @@ void Database_Privileges::load (string username, const string & data)
     sql.add (";");
     sql.execute ();
   }
+  
+  const std::vector <std::string> lines = filter::strings::explode (data, '\n');
+  bool loading_bibles {false};
+  std::string bible_value {};
+  int book_value {0};
+  bool write_value {false};
+  bool loading_features {false};
+  int counter {0};
 
-  vector <string> lines = filter_string_explode (data, '\n');
-  bool loading_bibles = false;
-  string bible_value;
-  int book_value = 0;
-  bool write_value = false;
-  bool loading_features = false;
-  int counter = 0;
-
-  for (auto & line : lines) {
+  for (const auto & line : lines) {
 
     if (line == bibles_end ()) {
       loading_bibles = false;
@@ -168,16 +167,16 @@ void Database_Privileges::load (string username, const string & data)
     
     if (loading_bibles) {
       if (counter == 1) bible_value = line;
-      if (counter == 2) book_value = convert_to_int (line);
+      if (counter == 2) book_value = filter::strings::convert_to_int (line);
       if (counter == 3) {
         write_value = (line == on ());
-        setBibleBook (username, bible_value, book_value, write_value);
+        set_bible_book (username, bible_value, book_value, write_value);
         counter = 0;
       }
     }
     
     if (loading_features) {
-      setFeature (username, convert_to_int (line), true);
+      set_feature (username, filter::strings::convert_to_int (line), true);
     }
     
     if (line == bibles_start ()) {
@@ -194,10 +193,10 @@ void Database_Privileges::load (string username, const string & data)
 
 
 // Give a privilege to a $username to access $bible $book to read it, or also to $write it.
-void Database_Privileges::setBibleBook (string username, string bible, int book, bool write)
+void DatabasePrivileges::set_bible_book (const std::string& username, const std::string& bible, const int book, const bool write)
 {
   // First remove any entry.
-  removeBibleBook (username, bible, book);
+  remove_bible_book (username, bible, book);
   // Store the new entry.
   SqliteDatabase sql (database ());
   sql.add ("INSERT INTO bibles VALUES (");
@@ -214,10 +213,10 @@ void Database_Privileges::setBibleBook (string username, string bible, int book,
 
 
 // Give a privilege to a $username to access $bible to read it, or also to $write it.
-void Database_Privileges::setBible (string username, string bible, bool write)
+void DatabasePrivileges::set_bible (const std::string& username, const std::string& bible, const bool write)
 {
   // First remove any entry.
-  removeBibleBook (username, bible, 0);
+  remove_bible_book (username, bible, 0);
   // Store the new entry.
   SqliteDatabase sql (database ());
   sql.add ("INSERT INTO bibles VALUES (");
@@ -236,7 +235,7 @@ void Database_Privileges::setBible (string username, string bible, bool write)
 // Read the privilege from the database whether $username has access to $bible $book.
 // The privileges are stored in $read for read-only access,
 // and in $write for write access.
-void Database_Privileges::getBibleBook (string username, string bible, int book, bool & read, bool & write)
+void DatabasePrivileges::get_bible_book (const std::string& username, const std::string& bible, const int book, bool & read, bool & write)
 {
   SqliteDatabase sql (database ());
   sql.add ("SELECT write FROM bibles WHERE username =");
@@ -246,7 +245,7 @@ void Database_Privileges::getBibleBook (string username, string bible, int book,
   sql.add ("AND book =");
   sql.add (book);
   sql.add (";");
-  vector <string> result = sql.query () ["write"];
+  const std::vector <std::string> result = sql.query () ["write"];
   if (result.empty()) {
     // Not in database: No access.
     read = false;
@@ -255,13 +254,13 @@ void Database_Privileges::getBibleBook (string username, string bible, int book,
     // Occurs in database: Read access.
     read = true;
     // Take write access from the database field.
-    write = convert_to_bool (result [0]);
+    write = filter::strings::convert_to_bool (result [0]);
   }
 }
 
 
 // Returns a tuple with <read, write> whether the $username has access to the given $bible.
-tuple <bool, bool> Database_Privileges::getBible (string username, string bible)
+std::tuple <bool, bool> DatabasePrivileges::get_bible (const std::string& username, const std::string& bible)
 {
   SqliteDatabase sql (database ());
   sql.add ("SELECT write FROM bibles WHERE username =");
@@ -269,8 +268,8 @@ tuple <bool, bool> Database_Privileges::getBible (string username, string bible)
   sql.add ("AND bible =");
   sql.add (bible);
   sql.add (";");
-  vector <string> result = sql.query () ["write"];
-  bool read = (!result.empty());
+  std::vector <std::string> result = sql.query () ["write"];
+  const bool read = (!result.empty());
   sql.clear ();
   sql.add ("SELECT write FROM bibles WHERE username =");
   sql.add (username);
@@ -278,24 +277,24 @@ tuple <bool, bool> Database_Privileges::getBible (string username, string bible)
   sql.add (bible);
   sql.add ("AND write;");
   result = sql.query () ["write"];
-  bool write = (!result.empty());
-  return make_tuple(read, write);
+  const bool write = (!result.empty());
+  return std::make_tuple(read, write);
 }
 
 
-int Database_Privileges::getBibleBookCount ()
+int DatabasePrivileges::get_bible_book_count ()
 {
   SqliteDatabase sql (database ());
   sql.add ("SELECT count(*) FROM bibles;");
-  vector <string> result = sql.query () ["count(*)"];
+  const std::vector <std::string> result = sql.query () ["count(*)"];
   if (result.empty ()) return 0;
-  return convert_to_int (result [0]);
+  return filter::strings::convert_to_int (result [0]);
 }
 
 
 // Returns true if a record for $username / $bible / $book exists in the database.
 // When the $book = 0, it takes any book.
-bool Database_Privileges::getBibleBookExists (string username, string bible, int book)
+bool DatabasePrivileges::get_bible_book_exists (const std::string& username, const std::string& bible, const int book)
 {
   SqliteDatabase sql (database ());
   sql.add ("SELECT rowid FROM bibles WHERE username =");
@@ -307,14 +306,14 @@ bool Database_Privileges::getBibleBookExists (string username, string bible, int
     sql.add (book);
   }
   sql.add (";");
-  vector <string> result = sql.query () ["rowid"];
+  const std::vector <std::string> result = sql.query () ["rowid"];
   return !result.empty();
 }
 
 
 // Remove the privilege of a $username to have access to $bible $book.
 // Removing the privilege for $book 0 removes them for all possible books.
-void Database_Privileges::removeBibleBook (string username, string bible, int book)
+void DatabasePrivileges::remove_bible_book (const std::string& username, const std::string& bible, const int book)
 {
   SqliteDatabase sql (database ());
   sql.add ("DELETE FROM bibles WHERE username =");
@@ -331,7 +330,7 @@ void Database_Privileges::removeBibleBook (string username, string bible, int bo
 
 
 // Remove data for $bible from the database.
-void Database_Privileges::removeBible (string bible)
+void DatabasePrivileges::remove_bible (const std::string& bible)
 {
   SqliteDatabase sql (database ());
   sql.add ("DELETE FROM bibles WHERE bible =");
@@ -341,7 +340,7 @@ void Database_Privileges::removeBible (string bible)
 }
 
 
-void Database_Privileges::setFeature (string username, int feature, bool enabled)
+void DatabasePrivileges::set_feature (const std::string& username, const int feature, const bool enabled)
 {
   SqliteDatabase sql (database ());
   sql.add ("DELETE FROM features WHERE username =");
@@ -362,7 +361,7 @@ void Database_Privileges::setFeature (string username, int feature, bool enabled
 }
 
 
-bool Database_Privileges::getFeature (string username, int feature)
+bool DatabasePrivileges::get_feature (const std::string& username, const int feature)
 {
   SqliteDatabase sql (database ());
   sql.add ("SELECT rowid FROM features WHERE username =");
@@ -370,14 +369,14 @@ bool Database_Privileges::getFeature (string username, int feature)
   sql.add ("AND feature =");
   sql.add (feature);
   sql.add (";");
-  vector <string> result = sql.query () ["rowid"];
+  const std::vector <std::string> result = sql.query () ["rowid"];
   if (result.empty()) return false;
   return true;
 }
 
 
 // Remove privileges for $username from the entire database.
-void Database_Privileges::removeUser (string username)
+void DatabasePrivileges::remove_user (const std::string& username)
 {
   SqliteDatabase sql (database ());
   sql.add ("DELETE FROM bibles WHERE username =");
@@ -392,64 +391,64 @@ void Database_Privileges::removeUser (string username)
 }
 
 
-const char * Database_Privileges::bibles_start ()
+const char * DatabasePrivileges::bibles_start ()
 {
   return "bibles_start";
 }
 
 
-const char * Database_Privileges::bibles_end ()
+const char * DatabasePrivileges::bibles_end ()
 {
   return "bibles_end";
 }
 
 
-const char * Database_Privileges::features_start ()
+const char * DatabasePrivileges::features_start ()
 {
   return "features_start";
 }
 
 
-const char * Database_Privileges::features_end ()
+const char * DatabasePrivileges::features_end ()
 {
   return "features_start";
 }
 
 
-const char * Database_Privileges::on ()
+const char * DatabasePrivileges::on ()
 {
   return "on";
 }
 
 
-const char * Database_Privileges::off ()
+const char * DatabasePrivileges::off ()
 {
   return "off";
 }
 
 
-string database_privileges_directory (const string & user)
+std::string database_privileges_directory (const std::string& user)
 {
   return filter_url_create_path ({database_logic_databases (), "clients", user});
 }
 
 
-string database_privileges_file ()
+std::string database_privileges_file ()
 {
   return "privileges.txt";
 }
 
 
-string database_privileges_client_path (const string & user)
+std::string database_privileges_client_path (const std::string& user)
 {
   return filter_url_create_root_path ({database_privileges_directory (user), database_privileges_file ()});
 }
 
 
-void database_privileges_client_create (const string & user, bool force)
+void database_privileges_client_create (const std::string& user, bool force)
 {
   // The path to the file with privileges for the $user.
-  string path = database_privileges_client_path (user);
+  std::string path = database_privileges_client_path (user);
   
   // Without $force, if the file exists, we're done.
   if (!force) {
@@ -457,20 +456,20 @@ void database_privileges_client_create (const string & user, bool force)
   }
   
   // If needed, create the folder.
-  string folder = filter_url_dirname (path);
+  std::string folder = filter_url_dirname (path);
   if (!file_or_dir_exists (folder)) filter_url_mkdir (folder);
   
   // The bits of privileges in human-readable form.
-  string privileges = Database_Privileges::save (user);
+  std::string privileges = DatabasePrivileges::save (user);
   
   // Write the privileges to disk.
   filter_url_file_put_contents (path, privileges);
 }
 
 
-void database_privileges_client_remove (const string & user)
+void database_privileges_client_remove (const std::string& user)
 {
-  string path = database_privileges_client_path (user);
+  std::string path = database_privileges_client_path (user);
   path = filter_url_dirname (path);
   filter_url_rmdir (path);
 }
