@@ -121,7 +121,7 @@ void demo_clean_data ()
   
   
   // Delete empty stylesheet that may have been there.
-  database::styles::revoke_write_access ("", styles_logic_standard_sheet ());
+  database::styles::revoke_write_access ("", stylesv2::standard_sheet ());
   database::styles::delete_sheet ("");
   styles_sheets_create_all ();
   
@@ -129,8 +129,8 @@ void demo_clean_data ()
   // Set both stylesheets to "Standard" for all Bibles.
   std::vector <std::string> bibles = database::bibles::get_bibles ();
   for (const auto & bible : bibles) {
-    database::config::bible::set_export_stylesheet (bible, styles_logic_standard_sheet ());
-    database::config::bible::set_editor_stylesheet (bible, styles_logic_standard_sheet ());
+    database::config::bible::set_export_stylesheet (bible, stylesv2::standard_sheet ());
+    database::config::bible::set_editor_stylesheet (bible, stylesv2::standard_sheet ());
   }
   
   
@@ -144,12 +144,12 @@ void demo_clean_data ()
 
   // Ensure the default users are there.
   std::map <std::string, int> users = {
-    std::pair ("guest", Filter_Roles::guest ()),
-    std::pair ("member", Filter_Roles::member ()),
-    std::pair ("consultant", Filter_Roles::consultant ()),
-    std::pair ("translator", Filter_Roles::translator ()),
-    std::pair ("manager", Filter_Roles::manager ()),
-    std::pair (session_admin_credentials (), Filter_Roles::admin ())
+    std::pair ("guest", roles::guest),
+    std::pair ("member", roles::member),
+    std::pair ("consultant", roles::consultant),
+    std::pair ("translator", roles::translator),
+    std::pair ("manager", roles::manager),
+    std::pair (session_admin_credentials (), roles::admin)
   };
   for (const auto & element : users) {
     if (!webserver_request.database_users ()->usernameExists (element.first)) {
@@ -185,7 +185,7 @@ void demo_clean_data ()
 
   // Set and/or trim resources to display.
   // Too many resources crash the demo: Limit the amount.
-  std::vector <std::string> resources = webserver_request.database_config_user()->getActiveResources ();
+  std::vector <std::string> resources = webserver_request.database_config_user()->get_active_resources ();
   bool reset_resources {false};
   size_t max_resource {25};
   if (resources.size () > max_resource) reset_resources = true;
@@ -196,12 +196,12 @@ void demo_clean_data ()
   }
   if (reset_resources) {
     resources = demo_logic_default_resources ();
-    webserver_request.database_config_user()->setActiveResources (resources);
+    webserver_request.database_config_user()->set_active_resources (resources);
   }
   
   
   // No flipped basic <> advanded mode.
-  webserver_request.database_config_user ()->setBasicInterfaceMode (false);
+  webserver_request.database_config_user ()->set_basic_interface_mode (false);
 }
 
 
@@ -281,7 +281,7 @@ void demo_prepare_sample_bible ()
       std::string usfm = filter_url_file_get_contents (file);
       usfm = filter::strings::collapse_whitespace (usfm);
       // Import the USFM into the sample Bible.
-      std::vector <filter::usfm::BookChapterData> book_chapter_data = filter::usfm::usfm_import (usfm, styles_logic_standard_sheet ());
+      std::vector <filter::usfm::BookChapterData> book_chapter_data = filter::usfm::usfm_import (usfm, stylesv2::standard_sheet ());
       for (const auto & data : book_chapter_data) {
         int book = data.m_book;
         if (book) {
@@ -342,7 +342,15 @@ void demo_create_sample_notes (Webserver_Request& webserver_request)
   std::vector <int> identifiers = database_notes.get_identifiers ();
   if (identifiers.size () < 10) {
     for (int i = 1; i <= 10; i++) {
-      database_notes.store_new_note (demo_sample_bible_name (), i, i, i, "Sample Note " + std::to_string (i), "Sample Contents for note " + std::to_string (i), false);
+      Database_Notes::NewNote new_note {
+        .bible = demo_sample_bible_name (),
+        .book = i,
+        .chapter = i,
+        .verse = i,
+        .summary = "Sample Note " + std::to_string (i),
+        .contents = "Sample Contents for note " + std::to_string (i),
+      };
+      database_notes.store_new_note (new_note);
     }
   }
 }
@@ -378,7 +386,7 @@ void demo_create_sample_workspaces (Webserver_Request& webserver_request)
     std::pair (2, "")
   };
   
-  webserver_request.database_config_user()->setActiveWorkspace ("USFM");
+  webserver_request.database_config_user()->set_active_workspace ("USFM");
   workspace_set_urls (webserver_request, urls);
   workspace_set_widths (webserver_request, widths);
   workspace_set_heights (webserver_request, row_heights);
@@ -386,7 +394,7 @@ void demo_create_sample_workspaces (Webserver_Request& webserver_request)
   urls[0] = editone_index_url ();
   urls[1] = resource_index_url ();
   
-  webserver_request.database_config_user()->setActiveWorkspace (demo_workspace ());
+  webserver_request.database_config_user()->set_active_workspace (demo_workspace ());
   workspace_set_urls (webserver_request, urls);
   workspace_set_widths (webserver_request, widths);
   workspace_set_heights (webserver_request, row_heights);
