@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2019 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -17,16 +17,12 @@
  */
 
 
-#ifndef INCLUDED_EDITONE_SAVE_H
-#define INCLUDED_EDITONE_SAVE_H
-
+#pragma once
 
 #include <config/libraries.h>
 
+class Webserver_Request;
 
-string editone_save_url ();
-bool editone_save_acl (void * webserver_request);
-string editone_save (void * webserver_request);
-
-
-#endif
+std::string editone_save_url ();
+bool editone_save_acl (Webserver_Request& webserver_request);
+std::string editone_save (Webserver_Request& webserver_request);
