@@ -17,9 +17,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-$ (document).ready (function () 
-{
-  $ (window).on ("keydown", editSwitchKeyHandler);
+document.addEventListener("DOMContentLoaded", function(e) {
+  window.addEventListener("keydown", editSwitchKeyHandler);
 });
 
 
