@@ -70,7 +70,7 @@ void export_info (std::string bible, bool log)
   
   
   // Save files.
-  filter_text.produceInfoDocument (informationdFilename);
+  filter_text.produce_info_document (informationdFilename);
   filter_text.produceFalloutDocument (falloutFilename);
   
   
@@ -78,5 +78,5 @@ void export_info (std::string bible, bool log)
   Database_State::clearExport (bible, 0, export_logic::export_info);
 
   
-  if (log) Database_Logs::log (translate("Documents with information and fallout were created") + " " + bible, Filter_Roles::translator ());
+  if (log) Database_Logs::log (translate("Documents with information and fallout were created") + " " + bible, roles::translator);
 }
