@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -37,30 +37,26 @@
 #include <olb/text.h>
 
 
-void export_onlinebible (string bible, bool log)
+void export_onlinebible (std::string bible, bool log)
 {
-  string directory = filter_url_create_path ({Export_Logic::bibleDirectory (bible), "onlinebible"});
+  std::string directory = filter_url_create_path ({export_logic::bible_directory (bible), "onlinebible"});
   if (!file_or_dir_exists (directory)) filter_url_mkdir (directory);
   
   
-  string filename = filter_url_create_path ({directory, "bible.exp"});
+  std::string filename = filter_url_create_path ({directory, "bible.exp"});
 
   
-  Database_Bibles database_bibles;
-  
-  
-  string stylesheet = Database_Config_Bible::getExportStylesheet (bible);
+  const std::string stylesheet = database::config::bible::get_export_stylesheet (bible);
   
   
   Filter_Text filter_text_bible = Filter_Text (bible);
   filter_text_bible.onlinebible_text = new OnlineBible_Text ();
-  vector <int> books = database_bibles.getBooks (bible);
+  std::vector <int> books = database::bibles::get_books (bible);
   for (auto book : books) {
-    vector <int> chapters = database_bibles.getChapters (bible, book);
+    std::vector <int> chapters = database::bibles::get_chapters (bible, book);
     for (auto chapter : chapters) {
-      string chapter_data = database_bibles.getChapter (bible, book, chapter);
-      chapter_data = usfm_remove_w_attributes (chapter_data);
-      chapter_data = filter_string_trim (chapter_data);
+      std::string chapter_data = database::bibles::get_chapter (bible, book, chapter);
+      chapter_data = filter::strings::trim (chapter_data);
       filter_text_bible.add_usfm_code (chapter_data);
     }
   }
@@ -68,8 +64,8 @@ void export_onlinebible (string bible, bool log)
   filter_text_bible.onlinebible_text->save (filename);
 
   
-  Database_State::clearExport (bible, 0, Export_Logic::export_online_bible);
+  Database_State::clearExport (bible, 0, export_logic::export_online_bible);
 
   
-  if (log) Database_Logs::log (translate("Exported to Online Bible") + " " + bible, Filter_Roles::translator ());
+  if (log) Database_Logs::log (translate("Exported to Online Bible") + " " + bible, roles::translator);
 }
