@@ -34,22 +34,17 @@ namespace filter::shell {
 
 
 // Container that indicates whether a given executable is absent from the system.
-#ifdef HAVE_CLOUD
 static std::set<Executable> absent_executables{};
-#endif
 
 
-#ifdef HAVE_CLOUD
 static void log_absent_executable_internal(const char* executable)
 {
   std::stringstream ss{};
   ss << "Command line tool " << std::quoted(executable) << " was not found";
   Database_Logs::log (ss.str());
 }
-#endif
 
 
-#ifdef HAVE_CLOUD
 static const char* get_executable_internal(const Executable executable)
 {
   switch (executable) {
@@ -73,10 +68,6 @@ static const char* get_executable_internal(const Executable executable)
       return "ldapsearch";
     case Executable::ls:
       return "ls";
-    case Executable::pdfinfo:
-      return "pdfinfo";
-    case Executable::pdftocairo:
-      return "pdftocairo";
     case Executable::ps:
       return "ps";
     case Executable::tar:
@@ -87,11 +78,12 @@ static const char* get_executable_internal(const Executable executable)
       return "which";
     case Executable::zip:
       return "zip";
+    case Executable::__start__:
+    case Executable::__end__:
     default:
       return "false";
   }
 }
-#endif
 
 
 #ifdef HAVE_CLOUD
@@ -110,7 +102,6 @@ void check_existence_executables()
 #endif
 
 
-#ifdef HAVE_CLOUD
 const char* get_executable(const Executable executable)
 {
   if (const auto iter = std::find(absent_executables.cbegin(), absent_executables.cend(), executable);
@@ -120,7 +111,6 @@ const char* get_executable(const Executable executable)
   }
   return get_executable_internal(executable);
 }
-#endif
 
 
 static std::string escape_argument (std::string argument)
