@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2023 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -26,31 +26,28 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <filter/string.h>
 #include <webserver/request.h>
 #include <database/books.h>
-#include <database/volatile.h>
+#include <database/temporal.h>
 #include <locale/translate.h>
 #include <menu/logic.h>
 #include <manage/users.h>
 #include <database/privileges.h>
-using namespace std;
 
 
-string manage_write_url ()
+std::string manage_write_url ()
 {
   return "manage/write";
 }
 
 
-bool manage_write_acl (void * webserver_request)
+bool manage_write_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  return roles::access_control (webserver_request, roles::manager);
 }
 
 
-string manage_write (void * webserver_request)
+std::string manage_write (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  string page {};
+  std::string page {};
 
   Assets_Header header = Assets_Header (translate("Read/write"), webserver_request);
   header.add_bread_crumb (menu_logic_settings_menu (), menu_logic_settings_text ());
@@ -61,48 +58,48 @@ string manage_write (void * webserver_request)
 
   int userid = filter::strings::user_identifier (webserver_request);
   
-  string user {};
-  if (request->query.count ("user")) {
-    user = request->query["user"];
-    Database_Volatile::setValue (userid, "manage_write_user", user);
+  std::string user {};
+  if (webserver_request.query.count ("user")) {
+    user = webserver_request.query["user"];
+    database::temporal::set_value (userid, "manage_write_user", user);
   }
-  user = Database_Volatile::getValue (userid, "manage_write_user");
+  user = database::temporal::get_value (userid, "manage_write_user");
   view.set_variable ("user", user);
   
-  string bible {};
-  if (request->query.count ("bible")) {
-    bible = request->query["bible"];
-    Database_Volatile::setValue (userid, "manage_write_bible", bible);
+  std::string bible {};
+  if (webserver_request.query.count ("bible")) {
+    bible = webserver_request.query["bible"];
+    database::temporal::set_value (userid, "manage_write_bible", bible);
   }
-  bible = Database_Volatile::getValue (userid, "manage_write_bible");
+  bible = database::temporal::get_value (userid, "manage_write_bible");
   view.set_variable ("bible", bible);
 
   auto [ bible_read_access, bible_write_access ] = DatabasePrivileges::get_bible (user, bible);
 
   // Toggle write access to Bible book.
-  if (!request->post.empty ()) {
-    string checkbox = request->post["checkbox"];
-    string s_book (checkbox);
+  if (!webserver_request.post.empty ()) {
+    std::string checkbox = webserver_request.post_get("checkbox");
+    std::string s_book (checkbox);
     s_book.erase (0, 4);
     int book = filter::strings::convert_to_int (s_book);
     if (book) {
       if (bible_read_access) {
-        bool checked = filter::strings::convert_to_bool (request->post ["checked"]);
+        bool checked = filter::strings::convert_to_bool (webserver_request.post_get("checked"));
         DatabasePrivileges::set_bible_book (user, bible, book, checked);
         database_privileges_client_create (user, true);
       }
     }
-    return string();
+    return std::string();
   }
 
   // Toggle write access to Testament.
-  string testament = request->query ["testament"];
+  std::string testament = webserver_request.query ["testament"];
   if (!testament.empty ()) {
     // Count the majority 'write' access situation for the Bible.
     int majority = 0;
-    vector <int> books = request->database_bibles ()->getBooks (bible);
+    std::vector <int> books = database::bibles::get_books (bible);
     for (auto & book : books) {
-      string type = database::books::book_type_to_string (database::books::get_type (static_cast<book_id>(book)));
+      std::string type = database::books::book_type_to_string (database::books::get_type (static_cast<book_id>(book)));
       if (type == testament) {
         bool read, write;
         DatabasePrivileges::get_bible_book (user, bible, book, read, write);
@@ -113,7 +110,7 @@ string manage_write (void * webserver_request)
     // Update the write access privileges for the books of the Testament,
     // by setting the write privileges to the opposite of the majority state.
     for (auto & book : books) {
-      string type = database::books::book_type_to_string (database::books::get_type (static_cast<book_id>(book)));
+      std::string type = database::books::book_type_to_string (database::books::get_type (static_cast<book_id>(book)));
       if (type == testament) {
         DatabasePrivileges::set_bible_book (user, bible, book, (majority < 0));
       }
@@ -123,15 +120,15 @@ string manage_write (void * webserver_request)
   }
   
   // Read or write access to display.
-  vector <int> books = request->database_bibles ()->getBooks (bible);
+  std::vector <int> books = database::bibles::get_books (bible);
   for (size_t i = 0; i < books.size (); i++) {
     int book = books[i];
-    string bookname = database::books::get_english_from_id (static_cast<book_id>(book));
-    string checkboxname = "book" + filter::strings::convert_to_string (book);
+    std::string bookname = database::books::get_english_from_id (static_cast<book_id>(book));
+    std::string checkboxname = "book" + std::to_string (book);
     bool read, write;
     DatabasePrivileges::get_bible_book (user, bible, book, read, write);
-    string checked = filter::strings::get_checkbox_status (write);
-    view.add_iteration ("write", { pair ("bookname", bookname), pair ("checkboxname", checkboxname), pair ("checked", checked) } );
+    std::string checked = filter::strings::get_checkbox_status (write);
+    view.add_iteration ("write", { std::pair ("bookname", bookname), std::pair ("checkboxname", checkboxname), std::pair ("checked", checked) } );
   }
   
   page += view.render ("manage", "write");
