@@ -47,7 +47,7 @@ std::string notes_bulk_url ()
 
 bool notes_bulk_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
+  return roles::access_control (webserver_request, roles::translator);
 }
 
 
@@ -69,27 +69,27 @@ std::string notes_bulk (Webserver_Request& webserver_request)
   std::string success, error;
 
   
-  std::vector <std::string> bibles = access_bible::bibles (webserver_request);
+  std::vector <std::string> bibles = {webserver_request.database_config_user()->get_consultation_notes_bible_selector()};
+  if (bibles.empty()) bibles = access_bible::bibles (webserver_request);
   int book = Ipc_Focus::getBook (webserver_request);
   int chapter = Ipc_Focus::getChapter (webserver_request);
   int verse = Ipc_Focus::getVerse (webserver_request);
-  int passage_selector = webserver_request.database_config_user()->getConsultationNotesPassageSelector();
-  int edit_selector = webserver_request.database_config_user()->getConsultationNotesEditSelector();
-  int non_edit_selector = webserver_request.database_config_user()->getConsultationNotesNonEditSelector();
-  std::string status_selector = webserver_request.database_config_user()->getConsultationNotesStatusSelector();
-  std::string bible_selector = webserver_request.database_config_user()->getConsultationNotesBibleSelector();
-  std::string assignment_selector = webserver_request.database_config_user()->getConsultationNotesAssignmentSelector();
-  bool subscription_selector = webserver_request.database_config_user()->getConsultationNotesSubscriptionSelector();
-  int severity_selector = webserver_request.database_config_user()->getConsultationNotesSeveritySelector();
-  int text_selector = webserver_request.database_config_user()->getConsultationNotesTextSelector();
-  std::string search_text = webserver_request.database_config_user()->getConsultationNotesSearchText();
+  Database_Notes::PassageSelector passage_selector = static_cast<Database_Notes::PassageSelector>(webserver_request.database_config_user()->get_consultation_notes_passage_selector());
+  int edit_selector = webserver_request.database_config_user()->get_consultation_notes_edit_selector();
+  auto non_edit_selector = static_cast<Database_Notes::NonEditSelector>(webserver_request.database_config_user()->get_consultation_notes_non_edit_selector());
+  const std::vector<std::string> status_selectors = webserver_request.database_config_user()->get_consultation_notes_status_selectors();
+  std::string assignment_selector = webserver_request.database_config_user()->get_consultation_notes_assignment_selector();
+  bool subscription_selector = webserver_request.database_config_user()->get_consultation_notes_subscription_selector();
+  auto severity_selector = static_cast<Database_Notes::SeveritySelector>(webserver_request.database_config_user()->get_consultation_notes_severity_selector());
+  const int text_selector = webserver_request.database_config_user()->get_consultation_notes_text_selector();
+  const std::string search_text = text_selector ? webserver_request.database_config_user()->get_consultation_notes_search_text() : "";
   
   
   int userid = filter::strings::user_identifier (webserver_request);
   
   
   // The admin disables notes selection on Bibles, so the admin sees all notes, even notes referring to non-existing Bibles.
-  if (webserver_request.session_logic ()->get_level () == Filter_Roles::admin ()) bibles.clear ();
+  if (webserver_request.session_logic ()->get_level () == roles::admin) bibles.clear ();
 
   
   
@@ -111,21 +111,21 @@ std::string notes_bulk (Webserver_Request& webserver_request)
   // This is done to remember them as long as this page is active.
   // Thus erroneous bulk operations on notes can be rectified somewhat easier.
   if (!subscribe && !unsubscribe && !assign && !unassign && !status && !severity && !bible && !erase) {
-    std::vector <int> identifiers = database_notes.select_notes (bibles,
-                                              book,
-                                              chapter,
-                                              verse,
-                                              passage_selector,
-                                              edit_selector,
-                                              non_edit_selector,
-                                              status_selector,
-                                              bible_selector,
-                                              assignment_selector,
-                                              subscription_selector,
-                                              severity_selector,
-                                              text_selector,
-                                              search_text,
-                                              -1);
+    Database_Notes::Selector selector {
+      .bibles = bibles,
+      .book = book,
+      .chapter = chapter,
+      .verse = verse,
+      .passage_selector = passage_selector,
+      .edit_selector = static_cast<Database_Notes::EditSelector>(edit_selector),
+      .non_edit_selector = non_edit_selector,
+      .status_selectors = status_selectors,
+      .assignment_selector = assignment_selector,
+      .subscription_selector = subscription_selector,
+      .severity_selector = severity_selector,
+      .search_text = search_text,
+    };
+    std::vector <int> identifiers = database_notes.select_notes (selector);
     std::vector <std::string> sids;
     for (auto id : identifiers) sids.push_back (std::to_string (id));
     database::temporal::set_value (userid, "identifiers", filter::strings::implode (sids, " "));
@@ -261,7 +261,7 @@ std::string notes_bulk (Webserver_Request& webserver_request)
   view.set_variable ("notescount", std::to_string (identifiers.size()));
 
   
-  bool manager = Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  bool manager = roles::access_control (webserver_request, roles::manager);
   if (manager) {
     view.enable_zone ("manager");
   }
