@@ -1,5 +1,5 @@
 /*
-Copyright (©) 2003-2024 Teus Benschop.
+Copyright (©) 2003-2025 Teus Benschop.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -17,26 +17,34 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 
-$(document).ready (function () {
+document.addEventListener("DOMContentLoaded", function(e) {
   navigationNewPassage ();
 });
 
 
 function navigationNewPassage ()
 {
-  $.ajax ({
-    url: "notes",
-    type: "GET",
-    cache: false,
-    success: function (response) {
-      var container = $ ("#noteslist");
-      container.empty ();
-      container.append (response);
-      if (window.self !== window.top) {
-        document.querySelectorAll('a').forEach((element) => {
-          element.href = topbarRemovalQueryAddition (element.href);
-        })
-      }
-    },
-  });
+  fetch("notes", {
+    method: "GET",
+    cache: "no-cache"
+  })
+  .then((response) => {
+    if (!response.ok) {
+      throw new Error(response.status);
+    }
+    return response.text();
+  })
+  .then((response) => {
+    var container = document.querySelector ("#noteslist");
+    container.innerHTML = "";
+    container.insertAdjacentHTML('beforeend', response);
+    if (window.self !== window.top) {
+      document.querySelectorAll('a').forEach((element) => {
+        element.href = topbarRemovalQueryAddition (element.href);
+      })
+    }
+  })
+  .catch((error) => {
+    console.log(error);
+  })
 }
