@@ -50,36 +50,54 @@ std::string notes_notes (Webserver_Request& webserver_request)
   Database_Notes database_notes (webserver_request);
 
   
-  std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->getBible());
-  int book = Ipc_Focus::getBook (webserver_request);
-  int chapter = Ipc_Focus::getChapter (webserver_request);
-  int verse = Ipc_Focus::getVerse (webserver_request);
+  const std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->get_bible());
+  const int book = Ipc_Focus::getBook (webserver_request);
+  const int chapter = Ipc_Focus::getChapter (webserver_request);
+  const int verse = Ipc_Focus::getVerse (webserver_request);
 
   
-  int passage_selector = webserver_request.database_config_user()->getConsultationNotesPassageSelector();
-  int edit_selector = webserver_request.database_config_user()->getConsultationNotesEditSelector();
-  int non_edit_selector = webserver_request.database_config_user()->getConsultationNotesNonEditSelector();
-  std::string status_selector = webserver_request.database_config_user()->getConsultationNotesStatusSelector();
-  std::string bible_selector = webserver_request.database_config_user()->getConsultationNotesBibleSelector();
-  std::string assignment_selector = webserver_request.database_config_user()->getConsultationNotesAssignmentSelector();
-  bool subscription_selector = webserver_request.database_config_user()->getConsultationNotesSubscriptionSelector();
-  int severity_selector = webserver_request.database_config_user()->getConsultationNotesSeveritySelector();
-  int text_selector = webserver_request.database_config_user()->getConsultationNotesTextSelector();
-  std::string search_text = webserver_request.database_config_user()->getConsultationNotesSearchText();
-  int passage_inclusion_selector = webserver_request.database_config_user()->getConsultationNotesPassageInclusionSelector();
-  int text_inclusion_selector = webserver_request.database_config_user()->getConsultationNotesTextInclusionSelector();
+  const auto passage_selector = static_cast<Database_Notes::PassageSelector>(webserver_request.database_config_user()->get_consultation_notes_passage_selector());
+  const int edit_selector = webserver_request.database_config_user()->get_consultation_notes_edit_selector();
+  const auto non_edit_selector = static_cast<Database_Notes::NonEditSelector>(webserver_request.database_config_user()->get_consultation_notes_non_edit_selector());
+  const std::vector<std::string> status_selectors = webserver_request.database_config_user()->get_consultation_notes_status_selectors();
+  const std::string bible_selector = webserver_request.database_config_user()->get_consultation_notes_bible_selector();
+  const std::string assignment_selector = webserver_request.database_config_user()->get_consultation_notes_assignment_selector();
+  const bool subscription_selector = webserver_request.database_config_user()->get_consultation_notes_subscription_selector();
+  const auto severity_selector = static_cast<Database_Notes::SeveritySelector>(webserver_request.database_config_user()->get_consultation_notes_severity_selector());
+  const bool text_selector = webserver_request.database_config_user()->get_consultation_notes_text_selector();
+  const std::string search_text = text_selector ? webserver_request.database_config_user()->get_consultation_notes_search_text() : "";
+  const bool passage_inclusion_selector = webserver_request.database_config_user()->get_consultation_notes_passage_inclusion_selector();
+  const bool text_inclusion_selector = webserver_request.database_config_user()->get_consultation_notes_text_inclusion_selector();
 
   
-  // The Bibles the current user has access to.
-  std::vector <std::string> bibles = access_bible::bibles (webserver_request, webserver_request.session_logic ()->get_username ());
+  // The Bibles the current user has access to or else the Bible selector.
+  std::vector<std::string> bibles{};
+  if (bible_selector.empty())
+    bibles = access_bible::bibles (webserver_request, webserver_request.session_logic ()->get_username ());
+  else
+    bibles = {webserver_request.database_config_user()->get_consultation_notes_bible_selector()};
   
   
   // The admin disables notes selection on Bibles,
   // so the admin sees all notes, including notes referring to non-existing Bibles.
-  if (webserver_request.session_logic ()->get_level () == Filter_Roles::admin ()) bibles.clear ();
+  if (webserver_request.session_logic ()->get_level () == roles::admin) bibles.clear ();
   
   
-  std::vector <int> identifiers = database_notes.select_notes (bibles, book, chapter, verse, passage_selector, edit_selector, non_edit_selector, status_selector, bible_selector, assignment_selector, subscription_selector, severity_selector, text_selector, search_text, -1);
+  Database_Notes::Selector selector {
+    .bibles = bibles,
+    .book = book,
+    .chapter = chapter,
+    .verse = verse,
+    .passage_selector = passage_selector,
+    .edit_selector = static_cast<Database_Notes::EditSelector>(edit_selector),
+    .non_edit_selector = non_edit_selector,
+    .status_selectors = status_selectors,
+    .assignment_selector = assignment_selector,
+    .subscription_selector = subscription_selector,
+    .severity_selector = severity_selector,
+    .search_text = search_text,
+  };
+  std::vector <int> identifiers = database_notes.select_notes (selector);
   
   
   // In case there aren't too many notes, there's enough time to sort them in passage order.
@@ -93,7 +111,7 @@ std::string notes_notes (Webserver_Request& webserver_request)
         numeric_passages.push_back (filter_passage_to_integer (passage));
       }
       if (!numeric_passages.empty ()) {
-        double average = static_cast<double>(accumulate (numeric_passages.begin (), numeric_passages.end (), 0)) / static_cast<double>(numeric_passages.size ());
+        double average = static_cast<double>(accumulate (numeric_passages.begin(), numeric_passages.end(), 0)) / static_cast<double>(numeric_passages.size());
         passage_sort_key = static_cast<int> (round(average));
       }
       passage_sort_keys.push_back (passage_sort_key);
@@ -102,9 +120,9 @@ std::string notes_notes (Webserver_Request& webserver_request)
   }
 
 
-  bool show_bible_in_notes_list = webserver_request.database_config_user ()->getShowBibleInNotesList ();
-  bool show_note_status = webserver_request.database_config_user ()->getShowNoteStatus ();
-  bool color_note_status = webserver_request.database_config_user ()->getUseColoredNoteStatusLabels ();
+  const bool show_bible_in_notes_list = webserver_request.database_config_user ()->get_show_bible_in_notes_list ();
+  const bool show_note_status = webserver_request.database_config_user ()->get_show_note_status ();
+  const bool color_note_status = webserver_request.database_config_user ()->get_use_colored_note_status_labels ();
   std::stringstream notesblock;
   for (auto & identifier : identifiers) {
 
