@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 #include <assets/view.h>
 #include <assets/page.h>
 #include <dialog/entry.h>
-#include <dialog/list.h>
+#include <dialog/select.h>
 #include <filter/roles.h>
 #include <filter/url.h>
 #include <filter/string.h>
@@ -42,7 +42,7 @@ std::string paratext_index_url ()
 
 bool paratext_index_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
+  return roles::access_control (webserver_request, roles::translator);
 }
 
 
@@ -56,49 +56,53 @@ std::string paratext_index (Webserver_Request& webserver_request)
 
   
   std::string bible = webserver_request.query ["bible"];
-
-  
-  if (webserver_request.query.count ("selectbible")) {
-    std::string select = webserver_request.query["selectbible"];
-    if (select == "") {
-      Dialog_List dialog_list = Dialog_List ("index", translate("Which Bible are you going to use?"), "", "");
-      dialog_list.add_query ("bible", bible);
-      std::vector <std::string> bibles = database::bibles::get_bibles();
-      for (auto & value : bibles) {
-        dialog_list.add_row (value, "selectbible", value);
-      }
-      page += dialog_list.run ();
-      return page;
-    } else {
-      bible = select;
-    }
-  }
   
   
   if (webserver_request.query.count ("disable")) {
-    database::config::bible::set_paratext_project (bible, "");
+    database::config::bible::set_paratext_project (bible, std::string());
     database::config::bible::set_paratext_collaboration_enabled (bible, false);
     filter_url_rmdir (Paratext_Logic::ancestorPath (bible, 0));
     bible.clear ();
   }
-
+  
+  
+  {
+    constexpr const char* identification {"selectbible"};
+    if (webserver_request.post_count(identification)) {
+      bible = webserver_request.post_get(identification);
+    }
+    // The selector contains an empty value plus all Bibles.
+    std::vector<std::string> values {std::string()};
+    for (const auto& value : database::bibles::get_bibles())
+      values.push_back(value);
+    dialog::select::Settings settings {
+      .identification = identification,
+      .values = values,
+      .selected = bible,
+      .parameters = { {"bible", bible} },
+    };
+    dialog::select::Form form { .auto_submit = true };
+    view.set_variable(identification, dialog::select::form(settings, form));
+  }
+  
   
   view.set_variable ("bible", bible);
-  if (!bible.empty ()) view.enable_zone ("bibleactive");
+  if (!bible.empty ())
+    view.enable_zone ("bibleactive");
   
   
   // Paratext Projects folder.
   std::string paratext_folder = database::config::general::get_paratext_projects_folder ();
-  if (!file_or_dir_exists (paratext_folder)) paratext_folder.clear ();
-  
+  if (!file_or_dir_exists (paratext_folder))
+    paratext_folder.clear ();
   if (webserver_request.query.count ("paratextfolder")) {
     Dialog_Entry dialog_entry = Dialog_Entry ("index", translate("Please enter the name of the Paratext projects folder"), paratext_folder, "paratextfolder", "");
     dialog_entry.add_query ("bible", bible);
     page += dialog_entry.run ();
     return page;
   }
-  if (webserver_request.post.count ("paratextfolder")) {
-    std::string folder = webserver_request.post ["entry"];
+  if (webserver_request.post_count("paratextfolder")) {
+    std::string folder = webserver_request.post_get("entry");
     if (file_or_dir_exists (folder)) {
       paratext_folder = folder;
       success = translate ("Paratext projects folder was set.");
@@ -107,9 +111,8 @@ std::string paratext_index (Webserver_Request& webserver_request)
       paratext_folder.clear ();
     }
   }
-
-  if (paratext_folder.empty ()) paratext_folder = Paratext_Logic::searchProjectsFolder ();
-
+  if (paratext_folder.empty ())
+    paratext_folder = Paratext_Logic::searchProjectsFolder ();
   database::config::general::set_paratext_projects_folder (paratext_folder);
   view.set_variable ("paratextfolder", paratext_folder);
   if (paratext_folder.empty ()) {
@@ -119,43 +122,39 @@ std::string paratext_index (Webserver_Request& webserver_request)
   }
 
   
-  // Paratext Project.
+  // The Paratext project.
   std::string paratext_project = database::config::bible::get_paratext_project (bible);
-  if (!file_or_dir_exists (filter_url_create_path ({paratext_folder, paratext_project}))) paratext_project.clear ();
-  
-  if (webserver_request.query.count ("paratextproject")) {
-    std::string project = webserver_request.query["paratextproject"];
-    if (project == "") {
-      Dialog_List dialog_list = Dialog_List ("index", translate("Which Paratext project are you going to use?"), "", "");
-      dialog_list.add_query ("bible", bible);
-      std::vector <std::string> projects = Paratext_Logic::searchProjects (paratext_folder);
-      for (auto & value : projects) {
-        dialog_list.add_row (value, "paratextproject", value);
-      }
-      page += dialog_list.run ();
-      return page;
-    } else {
-      paratext_project = project;
+  if (!file_or_dir_exists (filter_url_create_path ({paratext_folder, paratext_project})))
+    paratext_project.clear ();
+  {
+    constexpr const char* identification {"paratextproject"};
+    if (webserver_request.post_count(identification)) {
+      paratext_project = webserver_request.post_get(identification);
     }
+    std::vector<std::string> values {std::string()};
+    for (const auto & value : Paratext_Logic::searchProjects (paratext_folder)) {
+      values.push_back(value);
+    }
+    dialog::select::Settings settings {
+      .identification = identification,
+      .values = std::move(values),
+      .selected = paratext_project,
+      .parameters = { {"bible", bible} },
+    };
+    dialog::select::Form form { .auto_submit = true };
+    view.set_variable(identification, dialog::select::form(settings, form));
   }
-  
   database::config::bible::set_paratext_project (bible, paratext_project);
-  view.set_variable ("paratextproject", paratext_project);
-  if (!paratext_project.empty ()) view.enable_zone ("paratextprojectactive");
+  if (!paratext_project.empty ())
+    view.enable_zone ("paratextprojectactive");
 
 
   // Authoritative copy: Take from either Bibledit or else from Paratext.
-  if (webserver_request.query.count ("master")) {
-    std::string master = webserver_request.query["master"];
-    if (master == "") {
-      Dialog_List dialog_list = Dialog_List ("index", translate("Where are you going to take the initial Bible data from?"), "", "");
-      dialog_list.add_query ("bible", bible);
-      dialog_list.add_row (translate ("Bibledit"), "master", "bibledit");
-      dialog_list.add_row ("Paratext", "master", "paratext");
-      page += dialog_list.run ();
-      return page;
-    } else {
+  {
+    constexpr const char* identification {"master"};
+    if (webserver_request.post_count(identification)) {
       // Set collaboration up.
+      const std::string master = webserver_request.post_get(identification);
       tasks_logic_queue (task::setup_paratext, { bible, master });
       success = translate ("The collaboration will be set up");
       if (database::config::general::get_repeat_send_receive () == 0) {
@@ -165,7 +164,17 @@ std::string paratext_index (Webserver_Request& webserver_request)
       view.enable_zone ("setuprunning");
       redirect_browser (webserver_request, journal_index_url ());
       return std::string();
+      paratext_project = webserver_request.post_get(identification);
     }
+    dialog::select::Settings settings {
+      .identification = identification,
+      .values = { "", "bibledit", "paratext" },
+      .displayed = { "", "Bibledit", "Paratext" },
+      .selected = "",
+      .parameters = { {"bible", bible} },
+    };
+    dialog::select::Form form { .auto_submit = true };
+    view.set_variable(identification, dialog::select::form(settings, form));
   }
 
 
