@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 
 #include <config/libraries.h>
 
+class Webserver_Request;
+
 std::string read_verse_url ();
-bool read_verse_acl (void * webserver_request);
-std::string read_verse (void * webserver_request);
+bool read_verse_acl (Webserver_Request& webserver_request);
+std::string read_verse (Webserver_Request& webserver_request);
