@@ -42,7 +42,7 @@ std::string search_all_url ()
 
 bool search_all_acl (Webserver_Request& webserver_request)
 {
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::consultant ())) 
+  if (roles::access_control (webserver_request, roles::consultant)) 
     return true;
   auto [ read, write ] =  access_bible::any (webserver_request);
   return read;
