@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2022 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include <database/config/general.h>
 #include <database/config/bible.h>
 #include <access/bible.h>
-#include <dialog/list.h>
+#include <dialog/select.h>
 #include <sendreceive/logic.h>
 #include <demo/logic.h>
 #include <client/logic.h>
@@ -41,20 +41,20 @@
 #include <tasks/enums.h>
 
 
-string sendreceive_index_url ()
+std::string sendreceive_index_url ()
 {
   return "sendreceive/index";
 }
 
 
-bool sendreceive_index_acl (void * webserver_request)
+bool sendreceive_index_acl (Webserver_Request& webserver_request)
 {
   // In Client mode, also a Consultant can send/receive.
   if (client_logic_client_enabled ()) {
     return true;
   }
   // The role of Translator or higher enables send/receive.
-  if (Filter_Roles::access_control (webserver_request, Filter_Roles::translator ())) {
+  if (roles::access_control (webserver_request, roles::translator)) {
     return true;
   }
   // No access.
@@ -62,89 +62,79 @@ bool sendreceive_index_acl (void * webserver_request)
 }
 
 
-string sendreceive_index (void * webserver_request)
+std::string sendreceive_index (Webserver_Request& webserver_request)
 {
-  Webserver_Request * request = static_cast<Webserver_Request *>(webserver_request);
-
-  
-  if (request->query.count ("status")) {
-    vector <string> bits;
+  if (webserver_request.query.count ("status")) {
+    std::vector <std::string> bits;
     if (config_globals_syncing_bibles)    bits.push_back (translate ("Bibles"));
     if (config_globals_syncing_notes)     bits.push_back (translate ("Notes"));
     if (config_globals_syncing_settings)  bits.push_back (translate ("Settings"));
     if (config_globals_syncing_changes)   bits.push_back (translate ("Changes"));
     if (config_globals_syncing_files)     bits.push_back (translate ("Files"));
     if (config_globals_syncing_resources) bits.push_back (translate ("Resources"));
-    if (bits.empty ()) return "";
-    string status = translate ("Sending and receiving:") + " " + filter_string_implode (bits, ", ") + " ...";
+    if (bits.empty ()) return std::string();
+    std::string status = translate ("Sending and receiving:") + " " + filter::strings::implode (bits, ", ") + " ...";
     return status;
   }
   
   
-  string page;
-  Assets_Header header = Assets_Header (translate("Send/Receive"), request);
-  header.addBreadCrumb (menu_logic_tools_menu (), menu_logic_tools_text ());
+  std::string page;
+  Assets_Header header = Assets_Header (translate("Send/Receive"), webserver_request);
+  header.add_bread_crumb (menu_logic_tools_menu (), menu_logic_tools_text ());
   page = header.run ();
   Assets_View view;
   
   
-  string bible;
-  if (request->query.count ("bible")) {
-    bible = request->query["bible"];
-    if (bible.empty()) {
-      Dialog_List dialog_list = Dialog_List ("index", translate("Select a Bible"), "", "");
-      vector <string> bibles = AccessBible::Bibles (request);
-      for (auto & selectable_bible : bibles) {
-        // Select Bibles the user has write access to.
-        if (AccessBible::Write (request, selectable_bible)) {
-          dialog_list.add_row (selectable_bible, "bible", selectable_bible);
-        }
-      }
-      page += dialog_list.run ();
-      return page;
-    } else {
-      request->database_config_user()->setBible (bible);
+  std::string bible = access_bible::clamp (webserver_request, webserver_request.database_config_user()->get_bible ());
+  {
+    constexpr const char* identification {"bible"};
+    if (webserver_request.post_count(identification)) {
+      bible = webserver_request.post_get(identification);
+      webserver_request.database_config_user()->set_bible (bible);
     }
+    dialog::select::Settings settings {
+      .identification = identification,
+      .values = access_bible::bibles (webserver_request),
+      .selected = bible,
+    };
+    dialog::select::Form form { .auto_submit = true };
+    view.set_variable(identification, dialog::select::form(settings, form));
   }
-  
-  
-  bible = AccessBible::Clamp (request, request->database_config_user()->getBible ());
-  view.set_variable ("bible", bible);
 
 
-  string starting_to_sync;
-  if (Database_Config_Bible::getReadFromGit (bible)) {
+  std::string starting_to_sync;
+  if (database::config::bible::get_read_from_git (bible)) {
     starting_to_sync = translate ("Starting to send and receive now.");
   } else {
     starting_to_sync = translate ("Starting to send now.");
   }
   
   
-  if (request->query.count ("runbible")) {
+  if (webserver_request.query.count ("runbible")) {
     sendreceive_queue_bible (bible);
     view.set_variable ("successbible", starting_to_sync);
   }
   
   
-  string checkbox = request->post ["checkbox"];
-  bool checked = convert_to_bool (request->post ["checked"]);
+  std::string checkbox = webserver_request.post_get("checkbox");
+  bool checked = filter::strings::convert_to_bool (webserver_request.post_get("checked"));
   if (checkbox == "repeatbible") {
-    Database_Config_Bible::setRepeatSendReceive (bible, checked);
-    return "";
+    database::config::bible::set_repeat_send_receive (bible, checked);
+    return std::string();
   }
-  view.set_variable ("repeatbible", get_checkbox_status (Database_Config_Bible::getRepeatSendReceive (bible)));
+  view.set_variable ("repeatbible", filter::strings::get_checkbox_status (database::config::bible::get_repeat_send_receive (bible)));
   
     
   if (sendreceive_git_repository_linked (bible)) {
     view.enable_zone ("collab_on");
-    string url = Database_Config_Bible::getRemoteRepositoryUrl (bible);
+    std::string url = database::config::bible::get_remote_repository_url (bible);
     view.set_variable ("url", filter_url_remove_username_password (url));
   } else {
     view.enable_zone ("collab_off");
   }
   
   
-  if (request->query.count ("runsync")) {
+  if (webserver_request.query.count ("runsync")) {
     if (sendreceive_sync_queued ()) {
       view.set_variable ("error", translate("Still sending and receiving from the last time."));
     }
@@ -155,13 +145,13 @@ string sendreceive_index (void * webserver_request)
 
   {
     auto sync_method = tasks::enums::paratext_sync::none;
-    if (request->query.count ("syncparatext")) {
+    if (webserver_request.query.count ("syncparatext")) {
       sync_method = tasks::enums::paratext_sync::bi_directional;
     }
-    if (request->query.count ("bibledit2paratext")) {
+    if (webserver_request.query.count ("bibledit2paratext")) {
       sync_method = tasks::enums::paratext_sync::bibledit_to_paratext;
     }
-    if (request->query.count ("paratext2bibledit")) {
+    if (webserver_request.query.count ("paratext2bibledit")) {
       sync_method = tasks::enums::paratext_sync::paratext_to_bibledit;
     }
     if (sync_method != tasks::enums::paratext_sync::none) {
@@ -186,17 +176,17 @@ string sendreceive_index (void * webserver_request)
 #endif
 
   
-  if (request->query.count ("repeatsync")) {
-    int repeatsync = convert_to_int (request->query["repeatsync"]);
+  if (webserver_request.query.count ("repeatsync")) {
+    int repeatsync = filter::strings::convert_to_int (webserver_request.query["repeatsync"]);
     // Clamp the values.
     if (repeatsync < 0) repeatsync = 0;
     if (repeatsync > 2) repeatsync = 2;
-    Database_Config_General::setRepeatSendReceive (repeatsync);
+    database::config::general::set_repeat_send_receive (repeatsync);
   }
-  int repeatsync = Database_Config_General::getRepeatSendReceive ();
+  int repeatsync = database::config::general::get_repeat_send_receive ();
   // After removing value 3, if the setting had "3", make it "2".
   if (repeatsync > 2) repeatsync = 2;
-  string repeatsynczone = "repeatsync" + convert_to_string (repeatsync);
+  std::string repeatsynczone = "repeatsync" + std::to_string (repeatsync);
   view.enable_zone (repeatsynczone);
   
   
@@ -204,23 +194,27 @@ string sendreceive_index (void * webserver_request)
 
   
 #ifdef HAVE_PARATEXT
-  vector <string> bibles = Paratext_Logic::enabledBibles ();
+  std::vector <std::string> bibles = Paratext_Logic::enabledBibles ();
   if (!bibles.empty ()) {
     view.enable_zone ("paratexton");
-    view.set_variable ("paratextbibles", filter_string_implode (bibles, ", "));
+    view.set_variable ("paratextbibles", filter::strings::implode (bibles, ", "));
   } else {
     view.enable_zone ("paratextoff");
   }
 #endif
 
   
-  if (Database_Config_Bible::getReadFromGit (bible)) {
+  if (database::config::bible::get_read_from_git (bible)) {
     view.enable_zone ("gitreadwrite");
   } else {
     view.enable_zone ("gitwrite");
   }
+
+  
+  bool basic_mode = config::logic::basic_mode (webserver_request);
+  if (basic_mode) view.enable_zone("basicmode");
   
   page += view.render ("sendreceive", "index");
-  page += Assets_Page::footer ();
+  page += assets_page::footer ();
   return page;
 }
