@@ -21,7 +21,6 @@
 #include <assets/view.h>
 #include <assets/page.h>
 #include <dialog/entry.h>
-#include <dialog/list.h>
 #include <dialog/yes.h>
 #include <filter/roles.h>
 #include <filter/url.h>
@@ -47,7 +46,7 @@ std::string styles_indexm_url ()
 
 bool styles_indexm_acl (Webserver_Request& webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
+  return roles::access_control (webserver_request, roles::translator);
 }
 
 
@@ -64,8 +63,8 @@ std::string styles_indexm (Webserver_Request& webserver_request)
   const std::string& username {webserver_request.session_logic ()->get_username ()};
   int userlevel {webserver_request.session_logic ()->get_level ()};
   
-  if (webserver_request.post.count ("new")) {
-    std::string name {webserver_request.post["entry"]};
+  if (webserver_request.post_count("new")) {
+    std::string name {webserver_request.post_get("entry")};
     // Remove spaces at the ends of the name for the new stylesheet.
     // Because predictive keyboards can add a space to the name,
     // and the stylesheet system is not built for whitespace at the start / end of the name of the stylesheet.
@@ -92,11 +91,11 @@ std::string styles_indexm (Webserver_Request& webserver_request)
       std::string confirm {webserver_request.query ["confirm"]};
       if (confirm == "yes") {
         bool write = database::styles::has_write_access (username, del);
-        if (userlevel >= Filter_Roles::admin ()) write = true;
+        if (userlevel >= roles::admin) write = true;
         if (write) {
-          database::styles::delete_sheet (del);
-          database::styles::revoke_write_access (std::string(), del);
-          page += assets_page::success (translate("The stylesheet has been deleted"));
+          database::styles::delete_sheet(del);
+          database::styles::revoke_write_access(std::string(), del);
+          page += assets_page::success(translate("The stylesheet has been deleted"));
         }
       } if (confirm.empty()) {
         Dialog_Yes dialog_yes = Dialog_Yes ("indexm", translate("Would you like to delete this stylesheet?"));
@@ -116,9 +115,9 @@ std::string styles_indexm (Webserver_Request& webserver_request)
     sheetblock << "<p>";
     sheetblock << sheet;
     bool editable = database::styles::has_write_access (username, sheet);
-    if (userlevel >= Filter_Roles::admin ()) editable = true;
+    if (userlevel >= roles::admin) editable = true;
     // Cannot edit the Standard stylesheet.
-    if (sheet == styles_logic_standard_sheet ()) editable = false;
+    if (sheet == stylesv2::standard_sheet ()) editable = false;
     if (editable) {
       sheetblock << "<a href=" << std::quoted ("sheetm?name=" + sheet) << ">[" << translate("edit") << "]</a>";
     }
