@@ -1,5 +1,5 @@
 /*
- Copyright (©) 2003-2024 Teus Benschop.
+ Copyright (©) 2003-2025 Teus Benschop.
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -63,26 +63,26 @@ std::string sync_changes (Webserver_Request& webserver_request)
   sync_logic.prioritized_ip_address_record ();
 
   // Get the relevant parameters the client may have POSTed to us, the server.
-  std::string user = filter::strings::hex2bin (webserver_request.post ["u"]);
-  int action = filter::strings::convert_to_int (webserver_request.post ["a"]);
-  int id = filter::strings::convert_to_int (webserver_request.post ["i"]);
+  std::string user = filter::strings::hex2bin (webserver_request.post_get("u"));
+  int action = filter::strings::convert_to_int (webserver_request.post_get("a"));
+  int id = filter::strings::convert_to_int (webserver_request.post_get("i"));
 
   switch (action) {
     case Sync_Logic::changes_delete_modification:
     {
       // The server deletes the change notification.
       database::modifications::deleteNotification (id);
-      Database_Logs::log ("Client deletes change notification from server: " + std::to_string (id), Filter_Roles::translator ());
-      webserver_request.database_config_user ()->setChangeNotificationsChecksum ("");
+      Database_Logs::log ("Client deletes change notification from server: " + std::to_string (id), roles::translator);
+      webserver_request.database_config_user ()->set_change_notifications_checksum ("");
       return std::string();
     }
     case Sync_Logic::changes_get_checksum:
     {
       // The server responds with the possibly cached total checksum for the user's change notifications.
-      std::string checksum = webserver_request.database_config_user ()->getChangeNotificationsChecksum ();
+      std::string checksum = webserver_request.database_config_user ()->get_change_notifications_checksum ();
       if (checksum.empty ()) {
         checksum = Sync_Logic::changes_checksum (user);
-        webserver_request.database_config_user ()->setChangeNotificationsChecksum (checksum);
+        webserver_request.database_config_user ()->set_change_notifications_checksum (checksum);
       }
       return checksum;
     }
