@@ -43,7 +43,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <demo/logic.h>
 #include <resource/convert2resource.h>
 #include <resource/convert2bible.h>
-#include <resource/print.h>
 #include <resource/download.h>
 #include <statistics/statistics.h>
 #include <changes/modifications.h>
@@ -58,7 +57,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <export/info.h>
 #include <export/esword.h>
 #include <export/onlinebible.h>
-#include <manage/hyphenate.h>
 #include <paratext/logic.h>
 #include <resource/logic.h>
 #include <sword/logic.h>
@@ -129,10 +127,10 @@ void tasks_run_one (const std::string& filename)
     Database_Logs::rotate ();
   }
   else if (command == task::receive_email) {
-    email_receive ();
+    email::receive ();
   }
   else if (command == task::send_email) {
-    email_send ();
+    email::send ();
   }
   else if (command == task::reindex_bibles) {
     search_reindex_bibles (filter::strings::convert_to_bool (parameter1));
@@ -191,9 +189,6 @@ void tasks_run_one (const std::string& filename)
   else if (command == task::convert_resource_to_bible) {
     convert_resource_to_bible (parameter1);
   }
-  else if (command == task::print_resources) {
-    resource_print_job (parameter1, parameter2, parameter3);
-  }
   else if (command == task::notes_statistics) {
     statistics_statistics ();
   }
@@ -236,9 +231,6 @@ void tasks_run_one (const std::string& filename)
   else if (command == task::export_online_bible) {
     export_onlinebible (parameter1, filter::strings::convert_to_bool (parameter2));
   }
-  else if (command == task::hyphenate) {
-    manage_hyphenate (parameter1, parameter2);
-  }
   else if (command == task::setup_paratext) {
     Paratext_Logic::setup (parameter1, parameter2);
   }
@@ -247,9 +239,6 @@ void tasks_run_one (const std::string& filename)
     auto method = static_cast<tasks::enums::paratext_sync>(imethod);
     Paratext_Logic::synchronize (method);
   }
-  else if (command == task::import_images) {
-    resource_logic_import_images (parameter1, parameter2);
-  }
   else if (command == task::refresh_sword_modules) {
     sword_logic_refresh_module_list ();
   }
